Welcome to cc-pypackage's documentation!
========================================

cc-pypackage is my custom Cookiecutter_ template for a Python package.

Getting Started
---------------

.. toctree::
   :maxdepth: 2

   readme
   tutorial
   pypi_release_checklist

Basics
------

.. toctree::
   :maxdepth: 2

   prompts

Advanced Features
-----------------

.. toctree::
   :maxdepth: 2

   travis_pypi_setup
   console_script_setup


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
